==> Tegra_Multimedia_API_R24.2.1_aarch64.tbz2: tegra_multimedia_api/argus/docs/doxygen/html/search/all_73.js <==
var searchData=
[
  ['sensormode',['SensorMode',['../classArgus_1_1SensorMode.html',1,'Argus']]],
  ['sensorprivatemetadata_2eh',['SensorPrivateMetadata.h',['../SensorPrivateMetadata_8h.html',1,'']]],
  ['setaeantibandingmode',['setAeAntibandingMode',['../classArgus_1_1IAutoControlSettings.html#a5a67914a25c2b45e05a05b0706f14109',1,'Argus::IAutoControlSettings']]],
  ['setaelock',['setAeLock',['../classArgus_1_1IAutoControlSettings.html#aeb0065ad73870e6dde05606e78088551',1,'Argus::IAutoControlSettings']]],
  ['setaeregions',['setAeRegions',['../classArgus_1_1IAutoControlSettings.html#ae8b956909eff7e17a9a3a53a9f2f605c',1,'Argus::IAutoControlSettings']]],
  ['setawblock',['setAwbLock',['../classArgus_1_1IAutoControlSettings.html#ac14f7bf31f315c4f0f148aa17a30b312',1,'Argus::IAutoControlSettings']]],
  ['setawbmode',['setAwbMode',['../classArgus_1_1IAutoControlSettings.html#a37d259ea62879c41c89e993e137e487d',1,'Argus::IAutoControlSettings']]],
  ['setawbregions',['setAwbRegions',['../classArgus_1_1IAutoControlSettings.html#a487f7454abb8efddcbc90545ab7aaaaa',1,'Argus::IAutoControlSettings']]],
  ['setbayeraveragemapenable',['setBayerAverageMapEnable',['../classArgus_1_1Ext_1_1IBayerAverageMapSettings.html#a3123de1b0c0011223da00a9fb912be9d',1,'Argus::Ext::IBayerAverageMapSettings']]],
  ['setbayersharpnessmapenable',['setBayerSharpnessMapEnable',['../classArgus_1_1Ext_1_1IBayerSharpnessMapSettings.html#a0eeeb789780fafa47d743bfedf6b3c29',1,'Argus::Ext::IBayerSharpnessMapSettings']]],
  ['setcameradevice',['setCameraDevice',['../classArgus_1_1IOutputStreamSettings.html#ad746419d46b3e955525abdf2885419c5',1,'Argus::IOutputStreamSettings']]],
  ['setclientdata',['setClientData',['../classArgus_1_1IRequest.html#a55e55ea823ad98f286f2505c067458ac',1,'Argus::IRequest']]],
  ['setcolorcorrectionmatrix',['setColorCorrectionMatrix',['../classArgus_1_1IAutoControlSettings.html#a24001773f7a288aaa97b13f8181f5456',1,'Argus::IAutoControlSettings']]],
  ['setcolorcorrectionmatrixenable',['setColorCorrectionMatrixEnable',['../classArgus_1_1IAutoControlSettings.html#a4a822eb05bc4398d6c38f1a67fc9883b',1,'Argus::IAutoControlSettings']]],
  ['setcolorsaturation',['setColorSaturation',['../classArgus_1_1IAutoControlSettings.html#a0a94a306e28e90b5ca017c77e69c6436',1,'Argus::IAutoControlSettings']]],
  ['setcolorsaturationbias',['setColorSaturationBias',['../classArgus_1_1IAutoControlSettings.html#abc4e0e250193be956d444f03767f0178',1,'Argus::IAutoControlSettings']]],
  ['setcolorsaturationenable',['setColorSaturationEnable',['../classArgus_1_1IAutoControlSettings.html#a21009b33d8b636293f888752b1747eab',1,'Argus::IAutoControlSettings']]],
  ['setdefogamount',['setDeFogAmount',['../classArgus_1_1Ext_1_1IDeFogSettings.html#ab3540ae030b9b94ad0638c9c2d734790',1,'Argus::Ext::IDeFogSettings']]],
  ['setdefogenable',['setDeFogEnable',['../classArgus_1_1Ext_1_1IDeFogSettings.html#a457195ea6f2e2b40caa52045f6c1f85d',1,'Argus::Ext::IDeFogSettings']]],
  ['setdefogquality',['setDeFogQuality',['../classArgus_1_1Ext_1_1IDeFogSettings.html#afbd75c96d0766ebaff93824b1d4cb68e',1,'Argus::Ext::IDeFogSettings']]],
  ['setdenoisemode',['setDenoiseMode',['../classArgus_1_1IDenoiseSettings.html#af989064021965c35990fe83204d3b849',1,'Argus::IDenoiseSettings']]],
  ['setdenoisestrength',['setDenoiseStrength',['../classArgus_1_1IDenoiseSettings.html#ac9659df2f9f363c73d554befa0b785b1',1,'Argus::IDenoiseSettings']]],
  ['setedgeenhancemode',['setEdgeEnhanceMode',['../classArgus_1_1IEdgeEnhanceSettings.html#a600fc91a9d1695d33533d06c72a67570',1,'Argus::IEdgeEnhanceSettings']]],
  ['setedgeenhancestrength',['setEdgeEnhanceStrength',['../classArgus_1_1IEdgeEnhanceSettings.html#acb561fb70e4b51491a540597b8f050c7',1,'Argus::IEdgeEnhanceSettings']]],
  ['setegldisplay',['setEGLDisplay',['../classArgus_1_1IOutputStreamSettings.html#ab1cd470861b30e3b4e62f368c94cc94b',1,'Argus::IOutputStreamSettings']]],
  ['setexposurecompensation',['setExposureCompensation',['../classArgus_1_1IAutoControlSettings.html#a15dae0f7e79587f29226ec184b50f45d',1,'Argus::IAutoControlSettings']]],
  ['setexposuretimerange',['setExposureTimeRange',['../classArgus_1_1ISourceSettings.html#a97259077b42ecfb13d139da5ede8c2a1',1,'Argus::ISourceSettings']]],
  ['setfacedetectenable',['setFaceDetectEnable',['../classArgus_1_1Ext_1_1IFaceDetectSettings.html#ac16b0edce8d1b9d3c088aa3291c67227',1,'Argus::Ext::IFaceDetectSettings']]],
  ['setfifolength',['setFifoLength',['../classArgus_1_1IOutputStreamSettings.html#a1f5f2be5f7320f2c9f67cef5612ba605',1,'Argus::IOutputStreamSettings']]],
  ['setfocusposition',['setFocusPosition',['../classArgus_1_1ISourceSettings.html#acb57376b76666a116ba68c14b3856c3e',1,'Argus::ISourceSettings']]],
  ['setframedurationrange',['setFrameDurationRange',['../classArgus_1_1ISourceSettings.html#a46f05e2816befd695fd3ae68d856cf96',1,'Argus::ISourceSettings']]],
  ['setgainrange',['setGainRange',['../classArgus_1_1ISourceSettings.html#a9cdfb914b0e1da3a2f9fe4143f9c8e57',1,'Argus::ISourceSettings']]],
  ['setmetadataenable',['setMetadataEnable',['../classArgus_1_1Ext_1_1ISensorPrivateMetadataRequest.html#a3eec7c6b9d5cbe48399c8c658e0467c8',1,'Argus::Ext::ISensorPrivateMetadataRequest']]],
  ['setmode',['setMode',['../classArgus_1_1IOutputStreamSettings.html#a0c910f302391aec13473ef745027e48e',1,'Argus::IOutputStreamSettings']]],
  ['setpixelformat',['setPixelFormat',['../classArgus_1_1IOutputStreamSettings.html#a1f0b52f61a54a8cc1d6e589efc40af49',1,'Argus::IOutputStreamSettings']]],
  ['setpostprocessingenable',['setPostProcessingEnable',['../classArgus_1_1IStreamSettings.html#aab91aa8fe6d07ab356d43bcc7712f2a0',1,'Argus::IStreamSettings']]],
  ['setresolution',['setResolution',['../classArgus_1_1IOutputStreamSettings.html#a84ef5ad94d1bf938f4c689a0521d0e09',1,'Argus::IOutputStreamSettings']]],
  ['setsensormode',['setSensorMode',['../classArgus_1_1ISourceSettings.html#a50b962954ae6fcc9d024999390383071',1,'Argus::ISourceSettings']]],
  ['setsourcecliprect',['setSourceClipRect',['../classArgus_1_1IStreamSettings.html#a3d1bb539d1470030138973e97d713802',1,'Argus::IStreamSettings']]],
  ['settings_2eh',['Settings.h',['../Settings_8h.html',1,'']]],
  ['settonemapcurve',['setToneMapCurve',['../classArgus_1_1IAutoControlSettings.html#aebd8328d8378b02a48c7416a34d18127',1,'Argus::IAutoControlSettings']]],
  ['settonemapcurveenable',['setToneMapCurveEnable',['../classArgus_1_1IAutoControlSettings.html#a054d1626fcf4a159fa41e87efbfac1ee',1,'Argus::IAutoControlSettings']]],
  ['setvideostabilizationmode',['setVideoStabilizationMode',['../classArgus_1_1IVideoStabilizationSettings.html#a990304daa9fc2e10573a835676183a2a',1,'Argus::IVideoStabilizationSettings']]],
  ['setwbgains',['setWbGains',['../classArgus_1_1IAutoControlSettings.html#ab224517cee96b01c666c0a774ac533da',1,'Argus::IAutoControlSettings']]],
  ['size',['Size',['../structArgus_1_1Size.html',1,'Argus']]],
  ['size',['size',['../classArgus_1_1Array2D.html#a6a7cec989c652930564c0d5f83040b57',1,'Argus::Array2D::size()'],['../structArgus_1_1Size.html#ad9cb415b3f707412ed84ba7cd8fabc8f',1,'Argus::Size::Size()'],['../structArgus_1_1Size.html#a50e6baaf6af6c0abc6efbe004667ccd3',1,'Argus::Size::Size(uint32_t w, uint32_t h)']]],
  ['status',['Status',['../namespaceArgus.html#a43dee5758547aaf78710c7c1fe122fe3',1,'Argus']]],
  ['status_5fcancelled',['STATUS_CANCELLED',['../namespaceArgus.html#a43dee5758547aaf78710c7c1fe122fe3aa55fa5e99bf61b6ef7e4ae1ca5b8db66',1,'Argus']]],
  ['status_5fcount',['STATUS_COUNT',['../namespaceArgus.html#a43dee5758547aaf78710c7c1fe122fe3adaec86364eed23dc1c6ea5e218698594',1,'Argus']]],
  ['status_5fdisconnected',['STATUS_DISCONNECTED',['../namespaceArgus.html#a43dee5758547aaf78710c7c1fe122fe3a87c974d5788baff2ae26d4fe673744d3',1,'Argus']]],
  ['status_5finvalid_5fparams',['STATUS_INVALID_PARAMS',['../namespaceArgus.html#a43dee5758547aaf78710c7c1fe122fe3a5a8f53a6db51a77a4a98a6d860b05c6f',1,'Argus']]],
  ['status_5finvalid_5fsettings',['STATUS_INVALID_SETTINGS',['../namespaceArgus.html#a43dee5758547aaf78710c7c1fe122fe3aff5b73628bd366ea62cbd5c40e492daa',1,'Argus']]],
  ['status_5fok',['STATUS_OK',['../namespaceArgus.html#a43dee5758547aaf78710c7c1fe122fe3ac634101cfcda82a1bd2bdd36adf521e6',1,'Argus']]],
  ['status_5fout_5fof_5fmemory',['STATUS_OUT_OF_MEMORY',['../namespaceArgus.html#a43dee5758547aaf78710c7c1fe122fe3a1e691b265a31a18f6318793519652bda',1,'Argus']]],
  ['status_5ftimeout',['STATUS_TIMEOUT',['../namespaceArgus.html#a43dee5758547aaf78710c7c1fe122fe3a0e849c83b15d5a4a3451a0d836a77bd5',1,'Argus']]],
  ['status_5funavailable',['STATUS_UNAVAILABLE',['../namespaceArgus.html#a43dee5758547aaf78710c7c1fe122fe3a5458780eca91f8bf5cc550278a5024e6',1,'Argus']]],
  ['status_5funimplemented',['STATUS_UNIMPLEMENTED',['../namespaceArgus.html#a43dee5758547aaf78710c7c1fe122fe3a8e0e3b991e47acd63f5fb30bcd72eb1c',1,'Argus']]],
  ['stoprepeat',['stopRepeat',['../classArgus_1_1ICaptureSession.html#a49df8458b54d58fd5538c982565acd0e',1,'Argus::ICaptureSession']]],
  ['stream_2eh',['Stream.h',['../Stream_8h.html',1,'']]],
  ['supportsextension',['supportsExtension',['../classArgus_1_1ICameraProvider.html#acb729080a0071b42f9d4f801b18a17ca',1,'Argus::ICameraProvider']]]
];

==> Tegra_Multimedia_API_R27.1.0_aarch64.tbz2: tegra_multimedia_api/argus/docs/doxygen/html/search/all_73.js <==
var searchData=
[
  ['sensormode',['SensorMode',['../classArgus_1_1SensorMode.html',1,'Argus']]],
  ['sensorprivatemetadata_2eh',['SensorPrivateMetadata.h',['../SensorPrivateMetadata_8h.html',1,'']]],
  ['setaeantibandingmode',['setAeAntibandingMode',['../classArgus_1_1IAutoControlSettings.html#a5a67914a25c2b45e05a05b0706f14109',1,'Argus::IAutoControlSettings']]],
  ['setaelock',['setAeLock',['../classArgus_1_1IAutoControlSettings.html#aeb0065ad73870e6dde05606e78088551',1,'Argus::IAutoControlSettings']]],
  ['setaeregions',['setAeRegions',['../classArgus_1_1IAutoControlSettings.html#ae8b956909eff7e17a9a3a53a9f2f605c',1,'Argus::IAutoControlSettings']]],
  ['setawblock',['setAwbLock',['../classArgus_1_1IAutoControlSettings.html#ac14f7bf31f315c4f0f148aa17a30b312',1,'Argus::IAutoControlSettings']]],
  ['setawbmode',['setAwbMode',['../classArgus_1_1IAutoControlSettings.html#a37d259ea62879c41c89e993e137e487d',1,'Argus::IAutoControlSettings']]],
  ['setawbregions',['setAwbRegions',['../classArgus_1_1IAutoControlSettings.html#a487f7454abb8efddcbc90545ab7aaaaa',1,'Argus::IAutoControlSettings']]],
  ['setbayeraveragemapenable',['setBayerAverageMapEnable',['../classArgus_1_1Ext_1_1IBayerAverageMapSettings.html#a3123de1b0c0011223da00a9fb912be9d',1,'Argus::Ext::IBayerAverageMapSettings']]],
  ['setbayersharpnessmapenable',['setBayerSharpnessMapEnable',['../classArgus_1_1Ext_1_1IBayerSharpnessMapSettings.html#a0eeeb789780fafa47d743bfedf6b3c29',1,'Argus::Ext::IBayerSharpnessMapSettings']]],
  ['setcameradevice',['setCameraDevice',['../classArgus_1_1IOutputStreamSettings.html#ad746419d46b3e955525abdf2885419c5',1,'Argus::IOutputStreamSettings']]],
  ['setclientdata',['setClientData',['../classArgus_1_1IRequest.html#a55e55ea823ad98f286f2505c067458ac',1,'Argus::IRequest']]],
  ['setcolorcorrectionmatrix',['setColorCorrectionMatrix',['../classArgus_1_1IAutoControlSettings.html#a24001773f7a288aaa97b13f8181f5456',1,'Argus::IAutoControlSettings']]],
  ['setcolorcorrectionmatrixenable',['setColorCorrectionMatrixEnable',['../classArgus_1_1IAutoControlSettings.html#a4a822eb05bc4398d6c38f1a67fc9883b',1,'Argus::IAutoControlSettings']]],
  ['setcolorsaturation',['setColorSaturation',['../classArgus_1_1IAutoControlSettings.html#a0a94a306e28e90b5ca017c77e69c6436',1,'Argus::IAutoControlSettings']]],
  ['setcolorsaturationbias',['setColorSaturationBias',['../classArgus_1_1IAutoControlSettings.html#abc4e0e250193be956d444f03767f0178',1,'Argus::IAutoControlSettings']]],
  ['setcolorsaturationenable',['setColorSaturationEnable',['../classArgus_1_1IAutoControlSettings.html#a21009b33d8b636293f888752b1747eab',1,'Argus::IAutoControlSettings']]],
  ['setdefogamount',['setDeFogAmount',['../classArgus_1_1Ext_1_1IDeFogSettings.html#ab3540ae030b9b94ad0638c9c2d734790',1,'Argus::Ext::IDeFogSettings']]],
  ['setdefogenable',['setDeFogEnable',['../classArgus_1_1Ext_1_1IDeFogSettings.html#a457195ea6f2e2b40caa52045f6c1f85d',1,'Argus::Ext::IDeFogSettings']]],
  ['setdefogquality',['setDeFogQuality',['../classArgus_1_1Ext_1_1IDeFogSettings.html#afbd75c96d0766ebaff93824b1d4cb68e',1,'Argus::Ext::IDeFogSettings']]],
  ['setdenoisemode',['setDenoiseMode',['../classArgus_1_1IDenoiseSettings.html#af989064021965c35990fe83204d3b849',1,'Argus::IDenoiseSettings']]],
  ['setdenoisestrength',['setDenoiseStrength',['../classArgus_1_1IDenoiseSettings.html#ac9659df2f9f363c73d554befa0b785b1',1,'Argus::IDenoiseSettings']]],
  ['setedgeenhancemode',['setEdgeEnhanceMode',['../classArgus_1_1IEdgeEnhanceSettings.html#a600fc91a9d1695d33533d06c72a67570',1,'Argus::IEdgeEnhanceSettings']]],
  ['setedgeenhancestrength',['setEdgeEnhanceStrength',['../classArgus_1_1IEdgeEnhanceSettings.html#acb561fb70e4b51491a540597b8f050c7',1,'Argus::IEdgeEnhanceSettings']]],
  ['setegldisplay',['setEGLDisplay',['../classArgus_1_1IOutputStreamSettings.html#ab1cd470861b30e3b4e62f368c94cc94b',1,'Argus::IOutputStreamSettings']]],
  ['setexposurecompensation',['setExposureCompensation',['../classArgus_1_1IAutoControlSettings.html#a15dae0f7e79587f29226ec184b50f45d',1,'Argus::IAutoControlSettings']]],
  ['setexposuretimerange',['setExposureTimeRange',['../classArgus_1_1ISourceSettings.html#a97259077b42ecfb13d139da5ede8c2a1',1,'Argus::ISourceSettings']]],
  ['setfacedetectenable',['setFaceDetectEnable',['../classArgus_1_1Ext_1_1IFaceDetectSettings.html#ac16b0edce8d1b9d3c088aa3291c67227',1,'Argus::Ext::IFaceDetectSettings']]],
  ['setfifolength',['setFifoLength',['../classArgus_1_1IOutputStreamSettings.html#a1f5f2be5f7320f2c9f67cef5612ba605',1,'Argus::IOutputStreamSettings']]],
  ['setfocusposition',['setFocusPosition',['../classArgus_1_1ISourceSettings.html#acb57376b76666a116ba68c14b3856c3e',1,'Argus::ISourceSettings']]],
  ['setframedurationrange',['setFrameDurationRange',['../classArgus_1_1ISourceSettings.html#a46f05e2816befd695fd3ae68d856cf96',1,'Argus::ISourceSettings']]],
  ['setgainrange',['setGainRange',['../classArgus_1_1ISourceSettings.html#a9cdfb914b0e1da3a2f9fe4143f9c8e57',1,'Argus::ISourceSettings']]],
  ['setispdigitalgainrange',['setIspDigitalGainRange',['../classArgus_1_1IAutoControlSettings.html#ad2504986fcddc78fff56674c00c0d989',1,'Argus::IAutoControlSettings']]],
  ['setmetadataenable',['setMetadataEnable',['../classArgus_1_1Ext_1_1ISensorPrivateMetadataRequest.html#a3eec7c6b9d5cbe48399c8c658e0467c8',1,'Argus::Ext::ISensorPrivateMetadataRequest']]],
  ['setmode',['setMode',['../classArgus_1_1IOutputStreamSettings.html#a0c910f302391aec13473ef745027e48e',1,'Argus::IOutputStreamSettings']]],
  ['setpixelformat',['setPixelFormat',['../classArgus_1_1IOutputStreamSettings.html#a1f0b52f61a54a8cc1d6e589efc40af49',1,'Argus::IOutputStreamSettings']]],
  ['setpostprocessingenable',['setPostProcessingEnable',['../classArgus_1_1IStreamSettings.html#aab91aa8fe6d07ab356d43bcc7712f2a0',1,'Argus::IStreamSettings']]],
  ['setresolution',['setResolution',['../classArgus_1_1IOutputStreamSettings.html#a4e0e38647ba88c0d3c11d0addaae26d5',1,'Argus::IOutputStreamSettings']]],
  ['setsensormode',['setSensorMode',['../classArgus_1_1ISourceSettings.html#a50b962954ae6fcc9d024999390383071',1,'Argus::ISourceSettings']]],
  ['setsourcecliprect',['setSourceClipRect',['../classArgus_1_1IStreamSettings.html#afed99500f424659edacb8a55310311d2',1,'Argus::IStreamSettings']]],
  ['settings_2eh',['Settings.h',['../Settings_8h.html',1,'']]],
  ['settonemapcurve',['setToneMapCurve',['../classArgus_1_1IAutoControlSettings.html#ad4467e28d8f8cdec4a0069a6e2dfb2af',1,'Argus::IAutoControlSettings']]],
  ['settonemapcurveenable',['setToneMapCurveEnable',['../classArgus_1_1IAutoControlSettings.html#a054d1626fcf4a159fa41e87efbfac1ee',1,'Argus::IAutoControlSettings']]],
  ['setvideostabilizationmode',['setVideoStabilizationMode',['../classArgus_1_1IVideoStabilizationSettings.html#a990304daa9fc2e10573a835676183a2a',1,'Argus::IVideoStabilizationSettings']]],
  ['setwbgains',['setWbGains',['../classArgus_1_1IAutoControlSettings.html#ab224517cee96b01c666c0a774ac533da',1,'Argus::IAutoControlSettings']]],
  ['size',['size',['../classArgus_1_1Array2D.html#ab2cc11837aaf23d1ea9c7e361438b592',1,'Argus::Array2D']]],
  ['size2d',['Size2D',['../classArgus_1_1Size2D.html',1,'Argus']]],
  ['size2d',['Size2D',['../classArgus_1_1Size2D.html#a030cea1165690b1120f27eb8e42327a5',1,'Argus::Size2D::Size2D()'],['../classArgus_1_1Size2D.html#ac2715348690a4bae9170e4294915b25e',1,'Argus::Size2D::Size2D(const Tuple&lt; 2, T &gt; &amp;other)'],['../classArgus_1_1Size2D.html#ad6f5fab4c4b6686f4b97ab968ccd85d4',1,'Argus::Size2D::Size2D(T init)'],['../classArgus_1_1Size2D.html#a15d00d033095f2da873e92f1b346a812',1,'Argus::Size2D::Size2D(T _width, T _height)']]],
  ['size2d_3c_20uint32_5ft_20_3e',['Size2D&lt; uint32_t &gt;',['../classArgus_1_1Size2D.html',1,'Argus']]],
  ['status',['Status',['../namespaceArgus.html#a43dee5758547aaf78710c7c1fe122fe3',1,'Argus']]],
  ['status_5fcancelled',['STATUS_CANCELLED',['../namespaceArgus.html#a43dee5758547aaf78710c7c1fe122fe3aa55fa5e99bf61b6ef7e4ae1ca5b8db66',1,'Argus']]],
  ['status_5fcount',['STATUS_COUNT',['../namespaceArgus.html#a43dee5758547aaf78710c7c1fe122fe3adaec86364eed23dc1c6ea5e218698594',1,'Argus']]],
  ['status_5fdisconnected',['STATUS_DISCONNECTED',['../namespaceArgus.html#a43dee5758547aaf78710c7c1fe122fe3a87c974d5788baff2ae26d4fe673744d3',1,'Argus']]],
  ['status_5finvalid_5fparams',['STATUS_INVALID_PARAMS',['../namespaceArgus.html#a43dee5758547aaf78710c7c1fe122fe3a5a8f53a6db51a77a4a98a6d860b05c6f',1,'Argus']]],
  ['status_5finvalid_5fsettings',['STATUS_INVALID_SETTINGS',['../namespaceArgus.html#a43dee5758547aaf78710c7c1fe122fe3aff5b73628bd366ea62cbd5c40e492daa',1,'Argus']]],
  ['status_5fok',['STATUS_OK',['../namespaceArgus.html#a43dee5758547aaf78710c7c1fe122fe3ac634101cfcda82a1bd2bdd36adf521e6',1,'Argus']]],
  ['status_5fout_5fof_5fmemory',['STATUS_OUT_OF_MEMORY',['../namespaceArgus.html#a43dee5758547aaf78710c7c1fe122fe3a1e691b265a31a18f6318793519652bda',1,'Argus']]],
  ['status_5ftimeout',['STATUS_TIMEOUT',['../namespaceArgus.html#a43dee5758547aaf78710c7c1fe122fe3a0e849c83b15d5a4a3451a0d836a77bd5',1,'Argus']]],
  ['status_5funavailable',['STATUS_UNAVAILABLE',['../namespaceArgus.html#a43dee5758547aaf78710c7c1fe122fe3a5458780eca91f8bf5cc550278a5024e6',1,'Argus']]],
  ['status_5funimplemented',['STATUS_UNIMPLEMENTED',['../namespaceArgus.html#a43dee5758547aaf78710c7c1fe122fe3a8e0e3b991e47acd63f5fb30bcd72eb1c',1,'Argus']]],
  ['stoprepeat',['stopRepeat',['../classArgus_1_1ICaptureSession.html#a49df8458b54d58fd5538c982565acd0e',1,'Argus::ICaptureSession']]],
  ['stream_2eh',['Stream.h',['../Stream_8h.html',1,'']]],
  ['supportsextension',['supportsExtension',['../classArgus_1_1ICameraProvider.html#acb729080a0071b42f9d4f801b18a17ca',1,'Argus::ICameraProvider']]],
  ['supportsoutputstreamformat',['supportsOutputStreamFormat',['../classArgus_1_1IOutputStreamSettings.html#a17101752104e0b1d00aa92598e64ab12',1,'Argus::IOutputStreamSettings']]]
];
